package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$"`0`````````````"`!(````!``$;H````#0``,9$```!```T`"``
M!P`H`!L`&@````8````T``$`-``!`#0```#@````X`````4````$`````P``
M`10``0$4``$!%````!,````3````!`````$````!```````!`````0````"W
M#```MPP````%``$```````$``,````+````"P`````4T```5@`````<``0``
M`````@``P!0``L`4``+`%````/@```#X````!@````0````$```!*``!`2@`
M`0$H````1````$0````$````!&1TY5$`````````````````````````````
M``8````$+VQI8B]L9"UL:6YU>"YS;RXR```````$````$`````%'3E4`````
M``````(````&````$@````0````4`````T=.50"B(UFK!LOM6_[Z?"#U"Q#U
M#`A;]@```&$```!T````)@``````````````*P````````!-````:```````
M``!E````(0```%P```!/````'P````4```!6`````````#,```!=````<```
M`!@````H````%@```&L```!,```````````````-````0P```!T`````````
M``````\````#````.P````(```!N````:0```#@```!9````2@````````!F
M`````````&$`````````&0````L``````````````#4```!?`````````&``
M`````````````',````W````"0```&\``````````````$8`````````%0``
M````````````(@````````!>````*0````X````&````)0```"T`````````
M`````#`````:````.0```%````!'````/P```&H`````````5P``````````
M`````````#(````\`````````!X```!3````(P```"P```!B````)```````
M`````````````#0``````````````#T``````````````!P`````````.@``
M`````````````````````````````````%H``````````````%L````V````
M``````H`````````````````````````;````````````````````$@`````
M```````````````1`````````#X`````````3@`````````,````5```````
M``!5````$@`````````````````````````4```````````````!````+@``
M`&T````3````4@``````````````````````````````$``````````O````
M8P`````````;````6```````````````"`````<````$`````````#$````@
M````%P```$4```!1``````````````!+`````````'$```!$````````````
M`````````````````````````````'(```!D````)P`````````J````````
M``````!"````20````````!``````````````````````````&<`````````
M``````````!!````80````,````@````"@@`$J"A$48"````P!@1`%8\``C"
M$14`#0(0`````"@``````&`B6```"@0*H`>$1&!%"$`!A`!)ESQ"/@@``0`D
M@%`ADPQ@"%I`0'A``$```@`!``!``1L`A,",$)`0`@@`"8J)D!`!0<)`0)A`
M+(`@`$``"00@`.0!E(!(5I>.`````P`````````$````!0````<`````````
M````````````````"`````H````,````#0`````````.````$````!0`````
M````%0``````````````%@```!H````<````(````"$````B````)```````
M```E````)@```"D`````````*@```"L````L````+0```"X````O````,```
M```````T````-0`````````Y```````````````Z````.P```#P`````````
M/0```#X```!`````0@```$4`````````2````$D```!*````2P``````````
M`````````$X`````````````````````````4````%$`````````4P``````
M``!4````5@````````!7````6`````````!9````6@```%X`````````8```
M``````!B`````````&0```!F`````````&@```!I````:@```&L```!L````
M<!R3EE^0[UJC_X>.PAR3VU<+ESH-A`11T@V"=(%K2O!ZQ8Y!?:\,/\T@SB/W
M`K!T('S49-4H=U+@9LRO9O8]3BY>`/?;_X>D!^>=2+$*`J?@_ZY*SKS_^3XM
M1][/`<9'XJ\,0#D]X`[&Q85S;`*0/^Q\EGX_WDYO-9`%B<4B24EF$N^88:3Y
M(P$<D[N=9VB2H(&<^8;LU45##SN:6WR=34&$,(1QUNM5+6NCW:>O90"C'(OR
M.9[B%`P9]@*BGN/-VH6E,@5@;*'[[=MB,@[OT^H?0#G(#O&-N<+#^^D<D][M
MP.-+K1Q8<=DBX=`K<[$.++W6GQL?0#M8+#_EPVC4(IA\DN.Z#N3_(?II>F["
MW9B*5S79BV($K9/!\.,WR._R0WM?[^9/((7>&'SHFQ4BZ][):%I/0)RYQ0V"
MN#!??1M1;XL!LW#C;W9]2]"]UD,):Y`'J5-1$`(=I;4/"YN<J7Z"^M!BB_8L
M['R:?VM\EO"&_"R?T?E1"^X=T]OS#8)UD!!+9D-@=E]>S;)L!?%:ZA8-.:T]
MJ`W\*4G[X*-26I)7#^_2_4C^WRP?W\5N(`LBH.D0D'VVF\4N<;+5R)_*J][&
M!9A'`````````````````````````!$``````````"`````````@````````
M```@```````$-P`"Q+P`````$@```````PD``L($`````!(```````.=``+!
M:``````2```````#N0`"PZ@`````$@``````!1T``L4@`````"```!<```)Z
M``+!C``````2```````#E@`"Q%P`````$@```````FH``L+H`````!(`````
M``54``$S@````$02```-```#3@`"Q&@`````$@```````X$``L-(`````!(`
M``````/@``+!R``````2```````$K@`!4"````1@$@``#0```+$``L%<````
M`!(```````3H``$_`````8`2```-```$/@`"PDP`````$@```````U\``L.$
M`````!(```````/_``+#;``````2```````!4``"Q%``````$@``````!-(`
M`3A@````R!(```T```4&``+#5``````2```````$%@`"P[0`````$@``````
M!80``48````*&!(```T```21``$<X````%`2```-```#:``"P>P`````$@``
M`````XX``L&P`````!(```````/-``+"H``````2```````"0P`"Q(P`````
M$@```````T$``L3@`````!(```````&```+!X``````2```````$40`"Q4``
M```$(0``&````^H``L+<`````!(```````+Q``+$=``````2```````"^``"
MP5``````$@```````ZL``L,\`````!(```````&-``+!O``````2````````
MH``"PO0`````$@``````!&@``L4T`````!``__$```+K``+#D``````2````
M```#$0`"PF0`````$@```````1T``L2``````!(```````'^``+$.``````2
M```````$4@`"Q4`````$(0``&````.P``L/\`````!(```````/X``+%.```
M``01```8```$G@`!58`````($@``#0```AP``L(H`````!(```````4P``%5
MH````'02```-```"3@`"PYP`````$@``````!9$``3N@```!.!(```T```4A
M``$;H````#@2```-```$J``!5H``````$@``#@```W```L/8`````!(`````
M``4J``$;4``````2```,````UP`"Q"P`````$@```````Z0``L/P`````!(`
M``````,@``%6F`````01```/```$;P`"Q30`````$`#_\0``!!X``L,8````
M`!(````````T``+"T``````2```````$*``"Q"``````$@```````5T``L,`
M`````!(```````4H``%4@````#@2```-```!H0`"P8``````$@``````!'L`
M`M6``````!``__$```6C``%#X````A@2```-```#+P`"P?@`````$@``````
M`/T``L(<`````!(```````!X``+%!``````2```````"UP`"PE@`````$@``
M`````EP``L-X`````!(```````$+``+%$``````2```````%10`!6Q@``%OJ
M$0``#P```4$``L-@`````!(```````!C``+$L``````2```````!Z@`"PGP`
M````$@```````$(``L0(`````!(```````10``+%0`````01```8```#L@`"
MPC0`````$@```````<H``L)``````!(```````3$``$QP````&`2```-```#
MV``"PL0`````$@```````,@``L,,`````!(```````4;``+%(``````0```7
M```!;@`"P=0`````$@```````(\``L3(`````!(```````-&``+$[``````2
M```````$]``!/L`````H$@``#0```I@``L)P`````!(```````*%``+$1```
M```2```````$2P`!04````*8$@``#0```:8``L*(`````!(```````0/``+#
M,``````2```````$!@`"Q!0`````$@```````J,``L5(````$Q$``!@```/&
M``+#)``````2```````#P``"P^0`````$@```````2\``L*X`````!(`````
M``-6``+$U``````2```````$,``"PJP`````$@```````I$``L/``````!(`
M``````'8``+$I``````2```````%L``!/.````'0$@``#0```:L``L/,````
M`!(```````.(``+!=``````2```````"+``"PA``````$@``````!0\``4"`
M````J!(```T```5P``+%,`````01```7````5``"Q)@`````$@``````!(``
M`3E`````$!(```T```&W``+!F``````2```````"-0`"PI0`````$@``````
M!4```L4L````!!$``!<`;&EB<&5R;"YS;RXU+C$P`%]?9VUO;E]S=&%R=%]?
M`%]*=E]296=I<W1E<D-L87-S97,`4&5R;%]S>7-?=&5R;0!097)L7TES=&%T
M8G5F7W!T<@!097)L7W-Y<U]I;FET,P!097)L7TEE>&ET7V9L86=S7W!T<@!0
M97)L7W-A=F5?9&5S=')U8W1O<E]X`%!E<FQ?26-O;7!C=E]P='(`4&5R;%]A
M=&9O<FM?;&]C:P!097)L7TEC=7)S=&%C:VEN9F]?<'1R`'!E<FQ?8V]N<W1R
M=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?27!A<G-E<E]P='(`4&5R
M;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7TET;W!?96YV7W!T
M<@!097)L7TET86EN=&5D7W!T<@!097)L7W-V7W-E='!V;@!097)L7VYE=U-6
M<'8`4&5R;%]N97=84U]F;&%G<P!097)L7TEI;E]E=F%L7W!T<@!097)L7TEO
M<%]P='(`4&5R;%])979A;%]R;V]T7W!T<@!P97)L7V9R964`4&5R;%]M9U]S
M970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]'=&AR
M7VME>5]P='(`4&5R;%]'9&]?=6YD=6UP7W!T<@!097)L7TEP97)L7V1E<W1R
M=6-T7VQE=F5L7W!T<@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]D
M;W5N=VEN9`!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C
M:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL
M;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)D;"YS;RXR`&QI8FTN
M<V\N-@!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C:69I8P!C;&]S
M90!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`')E860`;&EB8RYS
M;RXV`%])3U]S=&1I;E]U<V5D`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W!R
M:6YT9@!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`'-T<FYC<'D`7U]S=&%C
M:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED
M`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!M96UC<'D`7U]L
M>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!?7V-T>7!E7V)?;&]C`'-T9&5R
M<@!G971U:60`<F5A9&QI;FL`97AE8W9P`&9P<FEN=&8`<F5A9&1I<C8T`&UE
M;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER
M;VX`;&EB8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!P87)?
M8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI8F-?8W-U7V9I;FD`6%-?
M26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?
M97AE8U]P<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W
M=6ED`'!A<E]C;&5A;G5P`%]?9&%T85]S=&%R=`!X<U]I;FET`%]?;&EB8U]C
M<W5?:6YI=`!N86UE7VQO861?;7E?<&%R7W!L`%A37TEN=&5R;F%L<U]005)?
M0TQ%05)35$%#2P!S:7IE7VQO861?;7E?<&%R7W!L`'!A<E]M:W1M<&1I<@!P
M87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`<&%R7VEN:71?96YV`$=,
M24)#7S(N-`!'3$E"0U\R+C,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXR`$=,24)#
M7S(N,`````````````,`!@`#``,``0````,````!``,``P`$``$````!``,`
M`P`#`````0`#``@``0`!``,``P`$`````P````,`!P`&``(``P```````0`"
M``(```````,````#``$````!`````0`!``$`"``!`````P`!``$`!`````,`
M```!`````0`!``4```````(```````$````````````#``,````!``,````!
M```````(``$```````$``P`#``,````#``,````#``,``P````$````#````
M`0`!`````0```````0````$`!0```Q8````0````8`UI:10````(```%O0``
M`!`-:6D3````!P``!<<````0"6D9<@````4```71````$`UI:1(````$```%
MW0```!`-:6D0`````P``!><```````$``@```L<````0``````UI:1(````&
M```%W0```!`-:6D0`````@``!><```````+!$````10```````+%.```+Q,`
M``````+%0```4!,```````+%2```81,```````+!4```)!4```````+!7```
M$!4```````+!:```!14```````+!=```:Q4```````+!@```0A4```````+!
MC```"!4```````+!F```<14```````+!I````14```````+!L```'!4`````
M``+!O```)A4```````+!R```#A4```````+!U```5Q4```````+!X```(!4`
M``````+![```&Q4```````+!^```114```````+"!```!!4```````+"$```
M;!4```````+"'```1A4```````+"*```,14```````+"-```414```````+"
M0```4A4```````+"3```$A4```````+"6```2!4```````+"9```*A4`````
M``+"<```6Q4```````+"?```3A4```````+"B```7A4```````+"E```<A4`
M``````+"H```'14```````+"K```9A4```````+"N```9!4```````+"Q```
M5!4```````+"T```/A4```````+"W```(A4```````+"Z```"A4```````+"
M]```)Q4```````+#````0!4```````+##```514```````+#&```/14`````
M``+#)```8A4```````+#,```7Q4```````+#/```)14```````+#2```#14`
M``````+#5```%Q4```````+#8```3!4```````+#;```%!4```````+#>```
M214```````+#A```$Q4```````+#D```*14```````+#G```,Q4```````+#
MJ```!A4```````+#M```&!4```````+#P```9Q4```````+#S```:A4`````
M``+#V```-Q4```````+#Y```8Q4```````+#\```.A4```````+#_```+A4`
M``````+$"```3Q4```````+$%```8!4```````+$(```/Q4```````+$+```
M.14```````+$.```+!4```````+$1```7!4```````+$4```%14```````+$
M7```"14```````+$:```#!4```````+$=```(Q4```````+$@```*Q4`````
M``+$C```'A4```````+$F```;Q4```````+$I```:!4```````+$L```314`
M``````+$O````Q4```````+$R```6!4```````+$U```914```````+$X```
M'Q4```````+$[```614```````+$^```.!4```````+%!```1Q4```````+%
M$```2A4`````@</@"*X#P!>=X[^@+P``:7____RN!>&T`P```((08`3"!<`!
M@*!@``*```0!````0`!IBP$```!```!``0```$``#J8!````@<?@"('H````
M`````````+P0``"<(Z`8T@.@6)0#H%P1``!0%P``51D``%60$B%`EA+AH)@3
M(8":$``!0`!IH`$```````````````````"=X[^@)P``L<(,X5R`H&``$D``
M&B4``+`C``"PI!2@"*(48`RB)$`2(0``L:,\8`+"!"%@H@1__X"@0!$Z0``.
M@A`@`:`4(6""`&`!PB0``(,H8`+"!(`!G\!```$```#"!```@*!`$0I/__F"
M`&`!@A`@`<(LX5R!S^`(`0```)WCOZ"!S^`(`0```#!H``4!`````0````$`
M```!````G>._H!$``+#"`B`0@*!@``)```F0$B`0`P```((08`"`H&```D``
M!`$```"?P$```0```('/X`@!`````0```)WCOZ"!S^`(`0```#!H``4!````
M`0````$````!````G>._H,@.``"%*2`8@*"@``)```Z&$``8"0``5H(&(`'(
M`2+TVDD``,@(0`"%.*`8@*"`#84I(!B'9$`!@*"@`!)/__J"`&`!@<_@")`0
M``,P:``$`0````$````!````G>.]R((0(`"(!B`<A@>^P,0!``'$(,`!@@!@
M!("@8$`R3__]Q`$``8('OO2:![_TQ@!_[,0`0`#(`'_4A!C``L8`?\R$&(`$
MA!B``X<PH!^$`(`"A!#``L0@8`R"`&`$@*!`#3)/__3&`'_LQ@8``!L6H)X%
M&[9ZV`8@!)H389F$$*.AU`8@"(DHX`4#(\;OU@>^P)$PX!N"$&#<T@8@#)`2
M``2("H`,X`8@$)XJ0`SH![[0H`0`"X@3P`3D![[4ERL@'J`$``WT![[@F3,@
M`I`$``CR![[HEA+`#-@'OL2(`@`$D"J``YXJP`3L![[LD@)`#)@*P`/X![[P
MF!(`#-`'OLB2`D`-D@)`#*@%``WN![[TE`*`"*0$@`WJ![[XD3$@&Z("@`V9
M*2`%N`<`#9@2``S0![[,K@7`#9@"0`RT!H`-E3#@`I`"``V3*.`>D`(`"Y(2
M0`JR!D`-E2L@!98)``FA,R`;EA/`"Z`4``J>*D`,E2D@'J`$0!#B![[8B3$@
M`I8$``N4$H`$J`4`"8@+``JF*H`+B!/`!*0$@`K>![[<E`(`!*($0`V3,N`;
MG@/`#8DJX`6L!8`-B!)`!-('ON2J!4`-D2L@'H@"@`29,R`"D@)`#94I(`60
M$@`,H3$@&Y@*P`B@%``*F!3`#)4JX!ZF*@`$ES+@`J`%`!#H![[\E!*`"Y@$
M``R6"0`*H"J`#)84P`N>`\`*Y@>_`)0$@`NB!$`(Y`>_!)$S(!NH!0`-ERL@
M!:0$@`V6$@`+I@3`#9$I(!Z6`H`+B3$@`I4JX`60$@`$NS+@&X@+``BZ%T`*
MB!0`!)4K(!Z@*@`+F3,@`J($0!V4$H`,B`1`!.('OPB8"L`*NBJ`!)@4``S@
M![\,H@1`#;0&@`B2`D`*H`0`#=H'OQB4`\`,D3$@&]X'OQ"9*2`%F@-``MHG
MOBR8$@`,V@>_')X#P`*8`H`,T`>_%)4JX!Z:`T`"VB>^,)<RX`*0`@`"MS,@
M&Y02@`N7*R`%F@D`"K86P`N:%T`-ERD@'K8&@!N),2`"F@;`#982P`2Z*H`,
MB`L`"[8JP`VZ%T`$K`6`"XDK8`6Z`D`=T@>_()<S8!NR!D`*U`>_)(@2P`36
M![\HD@)``H@'0`24`H`"M3$@&Y8"P`+6)[XT^@>_+)<K(!Z9,R`"EA+`#+H'
M0`+8![\T^B>^./H'OS"8`P`"V">^0)DI(`6Z!T`"M!:`#/HGOCR9*V`>N@M`
M"YLS8`*T!D`:F!,`#;86P!VV!H`;F@D`#+HJP`26!P`+NA=`#;@K`!N;+N`%
MF`7`#*\VX!NL!8`=^@>_.)H5P`WN![\\F@6`#>P'OT"Z!T`"M3-@&ZX%P`+N
M)[Y$[@>_1+(%@`*M*2`>B3$@`JX%P`+N)[Y(K!6`!,@'OTSN![](J@5`%H@!
M``+()[Y0B2M@!:X%P`+N)[Y,M!:`!*X.P!:)+N`>N!<`%[<VX`*6`L`:B!$`
M&Y8"P!RN+8`-N`M`!*X5P!RL*0`+^`>_4(@%``28`P`7J3+@&[@'``*O*N`%
MJ!4`%^X'OU28`P`4Z`>_6+8%P`+N![]<M`4``JDK8!ZN!<`"Q`>_8)LS8`+N
M)[Y4A`"``<0GOEBH%0`-Q`>_9*\S(!N:"L`4K!6`#:8$P!2$`(`!Q">^7)HM
M``R%*R`%KA7``H4JX!ZJ!4`7ES+@`JH%0!:$$(`+J`L``I8H@!6:$T`4A`2`
M`N@'OVBE-6`;B`$`#9LM8`6L!0`!J2L@'IH4@`WD![]LF3,@`H@!``W:![]P
MJ!4`#*X$@`&:`T`!VB>^8)@-0!3:![]TI3$@&Y82P`R8+0`$H@1`%)H#0`':
M)[YDV@>_>)H#0`':)[YHV@>_?)H#0`':)[YLFRD@!:04@`V;+6`>I`3`$JLU
M8`*6!(`+FA-`%:8)``VD*T`+F!,`$YH$``WF![^`H3+@&X0`@`R9*N`%J`3`
M`9@4``S@![^$A`"`#-@'OXBG,*`;J@0``>`'OXR8`P`!V">^<)DI(!Z@!``!
MX">^=(DQ(`+@![^0F!,`!,@'OY2@!``!X">^>(@!``'()[Y\H`K`#(DHH`6D
M%(`0IA3`!*`K``*)*N`>H@1`$Y<RX`*8`\`,W@>_G(@1``NB!$`2Y`>_H)8(
M@`2>`\`!WB>^@*`4``O6![^8D`(`!)H#0!"D!(`!Y">^A*$T8!NF`L`!Y`>_
MK)<HH!Z%,*`"I`2``>0GOHR?+&`%EA+``L0'OBR(&L`$GA0`#^0'O[2(&0`1
MF@-`#Y@#``3(![^HG@"`"\0'OZ2A,V`;B`$``<@GOHB)*V`%A`"``<0GOBR(
M%``$`S*8L(4L8!Z8`P`$R`>^,*,T8`*"$&'6A!"`$:0$@`&6&(`+H`$``HDK
M8!Z6&L`-FS-@`I`"``O6![^PHS,@&X@1``V$&0`"E@+``=8GOC":&(`,Q`>_
MN)("0`27*R`%G@/`#=H'O[R6%$`+A`"``<0GOI"0`@`+F@-``=HGOI2%*R`>
MX@>_P)DS(`*$$(`,H@1``9<R(!N(&(`$FRH@!90"@`*:$L`-G@/`#9H9``C(
M![_$F3/@&Z`$``W:![_(B`$``<@GOIB)*B`>F@-``=HGOIR1,B`"U@>_S)LK
MX`6($0`(T`>^-(09``*:$P`-F!B`#\0'O]"@!``-D@)`#-@'O]26`L`!A`"`
M`=8GOJ":`@`$Q">^-)<T(!N8`P`!A2O@'M@GOJ2?,^`"T`>_V)DL(`6$$(`/
MW@>_Y)@2P`S6![XXB!B`!)("0`R0`@`!T">^J)@"P`*6&0`0R`>_W)0"@`O6
M![_@G@/``9$R8!N(`0`!R">^.(DL(!Z6`L`!UB>^K*$T(`+>)[ZPERI@!8@1
M`!#@![_PEA(`"]`'OCR$&0`"E`*`"Z`$``'@)[ZXGS*@&Y8"``3@![_\D!B`
M"<0'O^B:`T`(T`>_[(8`P!"$`(`!Q">^/(4J8!Z0`@`!T">^M)$JH`63,F`"
MD!/`")H#0`B$$(`)T`>^0)\S8!N(&(`$D@(``I`9``K(![_TF`,`"-`'O_B(
M`0`!R">^0(DJH!Z0`@`!T">^O)4RH`*1*V`%B!$`"M0'OD20$\`(A!D``I@#
M``B$&(`-D`#``80"P`*#*V`>N@=`!)LS8`*7,R`;@A!`#8<K(`6(&$`$AA+`
M`Y89``R$`(`#D@)`"X<K(!Z:`H`!F3,@`I<HH`6&$,`,B3"@&X(8P`&($0`+
MF!A``M8'ODB2`D`$N@=`#(DHH!ZR!D`#A3"@`IDJ8`6($0`"@S)@&X89``."
M$$`,F!C`";H'0`&:`T`,@RI@'H0"P`23,F`"F2]@!8(00`F'-V`;B!A`!(80
MP`R6&0`=F@-``\8'ODRR!D`+B3-@&Y<K8`68`,`!AR]@'H@1``N[-V`"L@9`
M!,@'OE"&$,`=@AC``98!``.)*V`>E!A`#9LS8`*$`(`*@S9@&X@1``V5+F`%
MAAD``X(00`J:&,`9U`>^5(0`@`&8`P`-@RY@'K@'``2S-F`"FRB@!8(00!F'
M,*`;B!A`!(80P`V:&0`"F`,``Y8"P`V'**`>M@;``84PH`*;*R`%AA#``HDS
M(!N"&,`!B!$`#;0&@`.%*R`>E@+`!(@80`R9,R`"N`<`!(,RX!N$$(`,B2K@
M!888@`."$$`$FAC`"[@'``&V!L`-@RK@'H@"@`*7,N`"FR\@!8(00`O6![Y8
MAS<@&X080`*&$,`-F!B`'+8&P`.T!H`,AR\@'IH"P`&Y-R`"F2[@!880P!R%
M-N`;@AC``800@`R"&$`;M`:``H@!``&9-N`"A2[@'H,NH`6$$(`,ES:@&Y@0
M@`.6$L`!F`L`&H@!``N""(`#ERZ@'H(3``'8![Y<M3:@`IH#0`&6$L`:A@,`
M`X(2P`*L!8`"E3$@&X0*P`*9*2`%@@A`!)@2@`R"$$`"U`>^9(4I(!Z:`T`,
MB3$@`H8`P`&$$(`$K@7`"YDS8!N"$(`+B2M@!8((0`V($P`$E@B`"YDK8!Z&
M`,`$FS-@`H(00`N8$P`-V@>^8*P%@`&7,.`;B!,``H(#0`*("0`#FRC@!80+
M``*($0`"FA+`#84HX!Z:!8`-AS#@`JX%P`2$$(`#B`*`#)<K8`6&$(`,E3-@
M&Y@(@`R&",`-EA*`"X80P`S8![YHE@7`"Y4K8!Z"`$`#FS-@`H8#``*3,N`;
ME!*`#9DJX`6:$H`"F!)`#(0*@`*:"T`+@@!`#-@'OFR3,&`;FA-``H4JX!Z(
M`0`-ES+@`IH#``J$$(`+F!"`"I0(@`J7*&`%F`L``9820`N8$P`*U`>^=),H
M8!Z(`0`+@S!@`H8`P`R2$D`!J`4``H(20`*$"D`"ES$@&X((0`29*2`%@A!`
M`I@2P`R:`T`!A2D@'H8`P`R),2`"J@5`"9DPX!N$$(`$B2C@!8(0@`F($P`$
M@@A``YDHX!Z(`T`$V@>^<(<PX`*2"(`)F!,``X(00`F&$P`"J`4``88(P`2"
M`T`"ES$@&X0+``*;*2`%AA#``H4I(!Z:$L`-B3$@`IH%``V$$(`$J@5``X@0
M@`R&`H`,ERM@!9@(@`R5,V`;B`D`#8@1``R6$H`+V`>^>)4K8!Z6!4`+FS-@
M`H(`0`24$H`-B`,``I,RX!N:$H`"F2K@!80*@`*8$D`,F@M`"X(`0`R:$T`"
MV`>^?(4JX!Z&`,`-ES+@`IH#``J3,&`;A!"`"Y@0@`J4"(`*ERA@!9@+``&6
M$D`+F!,`"M0'OH"3*&`>A@#`"X,P8`*(`0`,DA)``:8$P`*7,.`;@A)``IDH
MX`6$"D`"@@A``Y@2P`R"$$`"B`$`#(4HX!Z:`T`!AS#@`H("@`F7,2`;A!"`
M`YDI(`6&$(`)F!+`#(8(P`27*2`>F@-`#-@'OH2),2`"D@B`"982P`2&$,`)
MB!+``J8$P`.("0`-A@,``I4S8!N$"L`"F2M@!8@1``*%*V`>F!*`#-0'OBR;
M,V`"F`3`#(00@`V"`$`$FA"`"X@"@`N3,R`;E@B`"Y4K(`6:"T`,E!)`"IH3
M0`O6![Z(DRL@'H(`0`J9,R`"A@#`#9(20`R:`L`"E3!@&Y@20`*7*&`%A`I`
M`I82@`N8"P`!U`>^C(8`P`N8$P`"A2A@'H@!``R#,&`"F`*`"9<HX`6$$(`!
ME3#@&X(0@`F6$H`+D@B`"8@!``N""$`#U@>^,)4HX!Z"$$`)AS#@`IH#0`&4
M$H`#@@+``I,Q(!N&$H`"ERD@!80*@`*6$D`+A@C`!)H#0`N&$,`"ERM@!9@#
M``.%*2`>I`2`"H<S8!N),2`"AA#`"X00@`28`P`#Q@>^D)<S(!N4&(`*E!J`
M#8@`P`*'*V`>@@!`"ILS8`*5*R`%AA#`#982P`K4![Z4A!C``ILK(!Z"`$`+
ME@*``Y08@`R9,R`"I`2`"H4P8!N:$T`,E2A@!88;0`.$$(`*F!C``:0$@`*(
M`0`,A2A@'J($0`V#,&`"F2R@!800@`&'-*`;FAB`#880P`S8![Z8FAM`$H(!
M``.:`L`-B3!@&X8#``*7*&`%F2R@'H@1``NE-*`"F@-`!)4S8!N8$P`2B!L`
M`L0'OIR(&0`!E@"`#*($0`2%*&`>@S!@`HDK8`6$$(`!F!B`#(@2@`34![Z@
MF!L`#8@$0`2#*V`>D@*``ILS8`*&`,`,E3$@&X(00`V9*2`%FAA``L0'OC28
M$H`,FAM`!(8`P`R8`(`!A2D@'I8"P`V),2`"E3#@&X00@`2;*.`%B!B``9H2
M@`V(&0`#F@+`#=8'OJ22`D`$@RC@'H<PX`*4`L`"B2M@!8(00`.7,V`;AAA`
M`L0'OJB&&,`-B!+`!)8`@`&(`D`$A2M@'I@#``.;,V`"DS$@&X00@`V'*2`%
MFAB``<('OCB&$D`#FAM`!(8#``.8`$`"@RD@'I0"@`V),2`"DS#@&X(00`2;
M*.`%B!A``L0'OJR:$D`-B!D``YH"@`V4`(`!A2C@'I8"P`2',.`"DS-@&X00
M@`.)*V`%AAB``<('OK"($D`$AAC`#8@"P`26`$`"@RM@'I@#``.;,V`"DS$@
M&X(00`V'*2`%FAA``L0'OCR&$D`#FAM`!(8#``.8`(`!A2D@'I0"@`V),2`"
MDS#@&X00@`2;*.`%B!B``<('OK2:$D`-B!D``YH"@`V4`$`"@RC@'I8"P`2'
M,.`"DS-@&X(00`/&![ZXB2M@!8080`*($D`$A!B`#8@"P`26`,`!ARM@'I@#
M``*;,V`"DS$@&X80P`V%*2`%FAC``<('OD"$$D`"FAM`!(0#``*8`$`#@RD@
M'I0"@`V),2`"DS"@&X(00`3(![Z\FRB@!8880`.:$D`-AAC``IH"@`V4`0`!
MB2B@'I8"P`.%,*`"DS-@&X@1``*'*V`%A!D``8820`.$&(`-A@+``Y@#``*7
M,.`;D`(`!(,K8!Z%*.`%FS-@`H02P`*"$$`-A`,``I<PH!N(&$`$FRC@'I@9
M``.)**`%F`*`#(<PX`*($L`$FA-``X8#``29,.`;EAM``8DHX`66&L`"E@(`
M"X@3``29**`>B`+`!,@F``#(!B`$A3"@`M8&(`B$$(`,A@$``]@&(`S(!B`0
MA`+``IH#``W&)B`$@@$``<0F(`C")B`0VB8@#('/X`@!````,&@`!@$````!
M`````0````$````!````G>._H("F(``20``$`P``L8'/X`B0$"``Y@!A0("D
MX``"3__\@A``&,1.``"&&*`]@*```X9`(`"`H``"A$`@`("(P`("2``-I!`@
M`((`8`'$2$``AAB@/8"@``.&0"``@*```H1`(`"`B,`",D__^8(`8`&D($`8
MX`3``("D(``"1__DHA``$Q!H``:0$``0X`1``("D(``"1__>D!``$)(0`!A`
M`&3!E!``$H"B(``R1__XH@1@!,),`!*`H&`],D__]*($8`2B)$`3I`2@`:,\
M8`+B)D``@<?@")'L`!*=X[^8D!``&'___\:2![_\@<?@")'H``@!`````0``
M`)WCOZ`A``"Q\`0A*("F/_\22``/$0``57____*0$B*@@*(@``)```RP$"``
MPDH``("@8``B2``&\"0A*((88#"`H``!L$`@`/`D(2B!S^`(`0```/`D(2B!
MS^`(`0```)WCOY@C``"QH`>__!!H``JB%&%`Q`1``(,H8`*"`(`!@@!@!,0`
M0`"`H*``$D?__<0@?_R0$``8?___FI(0`!"`HB``$D__],('O_R!S^`(`0``
M`#!H``,!`````0```)WCL``A/__[$0``5:`4(_B<`[^8H`>`$)`2(K"4$"__
MDA``$,(!X!3")[_\@A`@`$``9%D!````@*(@``1``"0!````H@(__\),`!&`
MH&```D@`'8"D8`"B$``((3__^Y(0("^@%"/XE!``$:`'@!!``&1;D!``$("B
M(``"0``4`0```$``9&B0$"``0`!CT]`"``"2$``9E!``$$``9!&6$``1Q`>_
M_,(!X!2$F(`!@A`@`!)```\!````@<_@"`$````23__G(3__^T``9%:0$"``
M0`!CP=`"``"2$``90`!CN)00`!H0;__O`0```$``9!H!`````0````$```"=
MX[^@D!`@`$``9$<S``!,T`(``+00(`!``&.PLA9CX$``8[V2$#__0`!D/Y`0
M(`!``&.JT`(``!"`9%.1Z``(`0```#!H``<!`````0````$````!`````0``
M``$```"=X[^@0`!D,)`0(`!``&.;T`(``$``8UH!````P@(``)`0(`!``&0H
MX`!@!$``8Y/0`@``0`!C<`$```#""@``D!`@`$``9"#"+"`80`!CB]`"``!`
M`&-*`0```,("``"0$"``0`!D&.``8`1``&.#T`(``$``8V,!````P@(``)`0
M(`#"`&`0@S!@%T``9`["-"`:0`!C>=`"``!``&,X`0```,("``"0$"``0`!D
M!N``8`1``&-QT`(``!,``%64$"``0`!CZY(28T#0)"`<0`!C_9`0(`!``&-H
MT`(``$``8R<!````P@(``)`0(`!``&/UX`!@!$``8V#0`@``0`!C-P$```#"
M`@``D!`@`$``8^W")"`@0`!C6-`"``!``&,7`0```,("``"0$"``0`!CY>``
M8`1``&-0T`(``$``8[<!````Q`(``("@H``"0``*@A`@`$``8]N0$"``0`!C
M1M`"``!``&.M`0```,("``#"`&!LPB0@)$``8]*0$"``0`!C/=`"``!``&+\
M`0```,("``"0$"``P@!@!$``8\G`(&`H0`!C--`"``!``&+S`0```,("``"0
M$"``P@!@!$``8\#`(&`L0`!C*]`"``!``&+J`0```,("``"0$"``0`!CN.``
M8`1``&,CT`(``$``8ZL!````P@(``,(D(#"!S^`(`0```#!H``4!`````0``
M``$````!````G>._.("F(``"0`!<`0```,).``"`H&``$D``!`$```"!S^`(
M`0```$``8R>0$``8HI(@``)'__LA``!5)0``52L``%6@%"+`I!2BR*H58M"H
M![^8+P``/"T``!!``&,OD!``$8"B(``"0``L`0```,(*(!/$#```@*!``@)(
M`"VZ`B`3Q`R``("@0`(B2``PQ`]@`4``8RJ0$``8IA``"$``8R>0$``=D`3`
M"$``8T60`B`"DA``%900`!B6$``=0`!CBZ80``B0$"`#DA``$T``8KZ4$``4
M@*(__P)```;"![^H@@A`%X"@0!8"0``E`0```$``8Q60$``30`!BXY`0`!-`
M`&,%D!``$8"B(``R3__9P@H@$T``8QN0$``10`!C,9`0`!B!S^`(`0```,8/
M8`'$#"`!@*#``@)/_\@!````$&__T<0,@`#"#*`!@*"``1)/_]`!````Q`]@
M`L(,H`*`H(`!`D__O0$````0;__)`0```('/X`@!````?___H)`0`!,0;__=
M`0```#!H``0!`````0````$```"=X[^@0`!C0)`0(`!``&*KT`(``$``8Q4!
M````E!``")(0`!A``&*WD!`@`X"B(``"0``$`0```('/X`B0$"``0`!C,2$`
M`#Q``&*<T`(``$``8P8!````Q`(@$`,``!"$"(`0@*"``2)```Z0$``80`!C
M)9`0(`!``&*0T`(``$``8OH!````P@(@$*`(0!`#```H@*0``1)/_^B0$``8
M0`!BFY(0(`*`H``(@<_@")!@/_\P:``#`0````$````#/__W@A!CD)WC@`'"
M`>`4PB>__((0(`!``&(\(3__^Z`4(_@3``!5H`>`$!<``%64$``(DA)BV)82
MXNA``&,4D!``$("B(``60``+(S__][`0(`#$![_\P@'@%(28@`&"$"``$D``
M%@$```"!S^`(`0```)`0`!"B%&/P%0``!*('@!%``&+,DA``$:"2(``&3__Q
ML!`@`$``8K*0!"`!L)(@``)'_^R2$``10`!BAI00`!`0;__HP"X`$$``8J\!
M`````0```#!H``8!`````0````$````!`````0```((3P``0O__'`0````$`
M```P:``$`0````$````!````G>._F,).0`""&&`]@*```;)F?_]``&)RD!``
M&:(0``B2![_\?__]SY`0`!B@DB```D``#R4``+%``&)I`0```("D0`@80`!V
M@A`@`,0.0`'$+``!A2B@&("@H``23__\@@!@`8'/X`B0$"``H!`@`-`$H4"2
M$"`(Q`(``("@H``"0``)@A``"((`8`3$`$``@*"@`!)/__V@!"`!D@0@`I,J
M8`(#``"QQ`!A:("@H``"2``*A!`@`4``8>:I+"`"T"2A0("B(``20``.IA``
M"('/X`B0$#__D!``"4``8F'$(&%HII(@``)/__JI+"`"T@2A0$``8G.4$``4
MYB2A0(($(`&#*&`"P"3``>`GO_S$3@``@A``&(@8H#V`H``$B$`@`("@``*$
M0"``@(D``@)```V&$"``@@!@`<1(0`"&&*`]@*```X9`(`"`H``"A$`@`("(
MP`(R3__Y@@!@`88@0!B0!&`"X`2A0$``8CV0`@`#@*(@``)'_];0)``4`P``
ML<8.``#$`&%`P@>__(,H8`+"`(`!A2C@&(4XH!B`H*```D``$L8H0`"`H*`]
M`D``$(00(#T0:``%L`8@`8"@H#T"0``+A!`@/<0.``""`&`!ARB@&,0H0`"%
M..`8@*"@`!)/__>P!B`!A!`@/<0H0`"$$"``Q@Y``H@`0`+&*2`!ARC@&("@
MX``23__[A`"@`1!O_Y0!````Z`>__"4``+$0;_^[J2T@`C!H``4!`````0``
M``$````!````G>._B`,``%8E``!5X`!B^`,``%4C``!5@A!C",(GO_`I``!5
M`P``5:04HO#D)[_H@A!C$,(GO_2B%&,``P``5>(GO^RH%2,P@A!C&,(GO_BF
M![_P`P``58(08T`0:``-PB>__$``8>D!````@*(@``)``!L!````PDQ``("@
M8``"0``5I!``$>($P`"F!.`$?__]7)`0`!*L$``(@*(@``)```:2$``8PDH`
M`("@8``23__M`0```)`0`!)___]!DA``&,),0`"`H&``$D__[Z00`!&!S^`(
M`0```$``8;"0$``8KA``"$``8:V0$``0JA``")`0`!9``&&IJ@7`%:H%8`%`
M`&''D`5`")(0`!24$``8EA``$)@0`!9``&(,JA``")`0`!)___\FDA``%1!O
M_]/"3$```0````$```"=X[]X!0``5A$``%6"$*+0[!BBT)`2(SC$$&`@(0``
M524``%74&&`0(P``52<``%78&&`8Z!A@",(!X!3")[_\@A`@`-0_O^C8/[_P
MQ#>_^.P_O]A___T[Z#^_X!$``%5___TXD!(C2!$``%5___TUD!(C4!$``%5_
M__TRD!(C8'___3"0%"-H$0``57___2V0$B-X?__]*Y`4HXA___TID!1BH'__
M_2>0%..8$0``57___220$B.H$0``57___2&0$B.X$0``57___1Z0$B/($0``
M57___1N0$B/8$0``57___/B0$B/HDI(@`")```41``!6?__^XY`4XY@1``!6
M?__\\)`2(`"`HB```D``!9(0``@1``!6?__^VI`2(!@1``!6?__\YY`2("B2
MDB```D``$!$``%9___[2D!2CB!,``%:0%"-H?__^SI(28&#$![_\P@'@%(28
M@`&"$"``$D``&0$```"!S^`(`0```'___-20$B`XDI(@`")```83``!6?__^
MOY`48J`0;__N$P``5I`'O^F2$F!00`!A>Y00(`J`HB``,D__YQ,``%:0%&*@
M?__^LY('O_,0;__B$P``5D``84T!`````0```#!H``0!`````0````$```"=
MX[^@0`!A*K`0(`!``&$B`0```("B(``R2``"\`(``('/X`@!````,&@`!@$`
M```!`````0````$````!````G>._H("F(``"0``I`0```,).``"`H&```D@`
M)0$```!``&$'D!``&)`"/_^4!@`(@*8`"AI``!,)``!6P@$B],9.``C$"$``
MA2B@&(,XH!B`H,`!(D@`")0"O_\0:``@A3B@&("@0`,R0``=A3B@&)0"O_^`
MI@`**D__^\)*@`"`HH`8$D``'L8!(O3P`2+TQ$J``,).``"`H(`!`D``+@$`
M```0@&%,@>@``$``8060$"`"@*(@``)```2"$"`NP"H@`<(J``"!Q^`(D>@`
M"("@0`("1__L@**`&)0"O_^`I@`**D__^\)*@`"`HH`8(D__Z/`!(O3&`2+T
ME`*__X"F``HZ0``(E"*`&,1*@`#"2,``@*"``2)/__J4`K__E"*`&`,```2$
M`J`"@*"``1A/_^:0$"``(0``L9(0`!B4`J`!0`!@:I`4(7`0;__?D!0A<$``
M8-N0$"`"@A``"("@8``"1__9D!`@`(00("[`*&`!D!```1!O_]3$*$``G>._
MH'___Y^0$``8Q`H``(,HH!B`H&```D``#J`0``@%``!6D`(@`<0`HO3&2(``
MQ`H``(,X8!B`H$`#@RB@&*%D0`B`H&``$D__^I`"(`%___P\`0```("B(``"
M0``.@*8@``)```P!````PDX``("@8``"0``($P``5I`0`!!``&"JDA)@:("D
M``@"0``$`0```('/X`@!````$&_].8'H```!````,&@`!@$````!`````0``
M``$````!````G>._F)`'H$22!Z!(\">@1)0'H$SR)Z!(0`!@T/0GH$P3``"P
M$0``L)(289B0$B+T0``$])00``E``&!!D!`@`,)*``"`H&``$D@`$0$```!`
M`&`X`0````4``+6`HB```D``B]`@H7!``&!9`0```$``8+V0$"``0`!@*-`"
M``!``&">`0```,`J``!``&"VD!`@`$``8"'0`@``0`!@M0$```""$``(D!`@
M`,0(0`"$$*`"0`!@K,0H0`!``&`7T`(``$``8*L!````P@H``(00(`""$&`!
MPBH``-`'H$0#``!6D`(@!880``C$/[_X!0``5M$?O_B5H!$(T1AC`)6BB$C1
M&*,(@:J*R"U``%P1``!60`!@?)$J(`+6!Z!(!0``M8@0(`30(*%\@A``",8"
MP`#$!Z!$QB(```<``+7((.%X!P``5H"@H`&&$.!XQB(@!`<``%:&$.,8QB(@
M"`<``%:&$."`!$``"\8B(`R&$"`$B!`@`=@"P`.:`$`#B`$@`88`X`2`H(`$
M%$__^]@C8`R$`*`#(0``M=`$(7"4$``"$P``584HH`*2$F#`EA```9@0(`!`
M`%^EP"!``K"2(``"0``0`0```$``8"30!"%P$0``57__^Z*0$B-X@*(@``)`
M`!,C``"U0`!?E=`$(7!``%_G`0```('/X`@!````0`!?L]`$(7"P$``(0`!@
M$]`$(7`1``!5?__[D9`2(WB`HB``$D__\2,``+70!&%T@*(@`")```H1``!5
M?___0`$```!``%]^T`0A<$``7]`!````@<_@"`$```!___N`D!(CB("B(``"
M3__@T"1A=!!O__,!````$P``L9`2('!``&`:DA)A2$``8$60$"`!`0````$`
M```!````G>.P`!$``%6<`[^8P@'@%,(GO_R"$"``?__[:I`2(X@#``!6HA``
M".``8O20$``80`!?YI(0`!"`HB```D``#@$````1``!5DA``&'___4V0$B.X
MQ`>__,(!X!2$F(`!@A`@`!)``&H!````@<_@"`$```!``%^ZD!``&`,``%:J
M$``(Y@!B^)`0`!E``%_ADA``$[B2(``"1__K)3__^RD``%6D%*/X+0``5:@5
M(L"J!6`!I`>`$JP5HS`[```\+P``(,)/``"`H&``N61`%("D8``"0``'D!``
M$4``8`"2$``<@*(@``)``#4!````0`!?FY`0`!R"!P`(Q$P``,9(?_^`H,`"
M,D``#)`%0`C`*'__D`(__\8(?_[$3```ARC@&(<XX!B`H,`"`D__^8(`?_^0
M!4`(@*(O_Q1'_\*4$``<DA``%I80`!"8$``80`!?[Y`0`!)``%_;D!`@`$``
M7T;0`@``0`!?L`$```"4$``(DA``$D``7QR0$"`#@*(@`#)(``Z0$"``0`!?
MS@$```!``%\YT`(``$``7Z,!````P@(@$(((0!V`H$`7`D``"I`0`!*0$"``
M0`!?E9(0`!.XDB``,D__P,)/```0;_^>$0``54``7SV2$"`!@*(@`#)/__:0
M$"``$0``59(0`!)___SCD!(CN$``7[Z0$``2$&__E+`0``A``%][`0````$`
M```!`````0````,__]^"$&)0G>.``0D__]\7``!6FA$C/)82X)#"`>`4PB>_
M_((0(`"$!X`-AA$C3-8@H`07``!5B!$C))82XL#6(*`(@@>`!!<``%8C``!5
MEA+@F-8@8`28!X`#%P``5J`48T#@(&`4EA+@H-8@8`@E``!5%P``5I`4HXC@
M(*`,EA+@J-8@8`PI``!6%P``5B<``%;@(R`(EA+@L-8@8!`#``!6@A!@P"L`
M`%;"(R`$J!4@B*84X!CH)X`-JA5@N.8G@`1___JWZB>``ZR2(``"0``&`0``
M`,)-@`"`H&``$D`!$0$```!___WV`0```*R2(``"0`$2+S__W^H-@`"K+6`8
M@*5@`")``!,K/__?0`!>\P$```""$``6AA`@7\0"``"K/6`7Q!"`%8"(J``B
M2``"QBA``((`8`'J"$``JRU@&("E8``R3__WQ`(``"L__]^0$``3JA5C)*H'
M@!40:``&J@5@!,)*``"`H&```D``UZH%8`1___J*`0```*:2(``B1__YT`5`
M`'___`4!````@*(@`")/__30!4``0`!?39`0`!.NDB``(D__[]`%0`!``%[B
MD!``%Z@0``A``%[?D!``%J@%``BH!20$0`!>_)`0`!2F$``(0`!>^9`0`!0#
M``!6$P``5NH`8O09``!6DA)@T)00`!>8$R!HFA``%I80`!5``%\YJ!``")`0
M`!1``%Y8DA`AP("B/_\"0`"++3__WY`0(`.L%:*XDA``%*P'@!9``%Z:E!``
M%H"B/_\"0`'"`P``/,0%H!"$"(`!`P``$("@@`$20`"-`P``L4``7L+N!:`8
M@*7`"!)``(@#``"QP@6@$(((8?^`H&'`$D``@A$``%5___I%D!(C$("B(``B
M0``*[`8``$``7PWL!@``DA``"'___LV0$``6K)(@`")```+L!@``0`!>GY`0
M`!:`HB`#!$@`(ZX0``B0`C_\$P``5I`%@`A``%[WDA)A@("B(``R2``<KA``
M%H"EX`0"0``'K@6`%\)-0`#$3?_[@*"``1)(`!2N$``6[@8@!("EX``B0``0
MKA``%D``7H:0$``7@*(@`RA(``NN$``6D`(__!,``%:0!<`(0`!>WI(288B`
MHB```D@``P$```"N$``6?__Z&;`0`!.`HB``$D@`"1,``%:0$``70`!>P)(0
M(`"LDB``,D``A1,___\3``!6$0``59(28&!___OSD!(BH$``7?,M``!6$P``
M5I@0``B:%&-`D!``$Y(28:B4$``40`!>S)80`!6B$"``$&@`$JP5H;A``%W@
M`0```,("``"`H&`1$D``$@$```!``%W@H@1@`>`CH%R8$``(DA``%I`0`!.4
M$``4EA``%4``7KF:$``1D!``$T``7=B2$"'`@*(__P)/_^P!````0`!>&)`0
M`!20%*.(?__[RY(0`!-___Q9D!``$Q!H`!H!````0`!=P0$```#8`@``@*,@
M$0)/_W,!`````P``L=0&```3``!6T`!A.)(28."6$``40`!>3K`0(``0:``*
M`0````,``+'4!@``$P``5M``83B2$F%8EA``%$``7D2P$"``Q`>__,(!X!2$
MF(`!@A`@`!)``50!````@<_@"`$````G/__?IA3C/*8'@!,0:``&I@3@!,)-
M``"`H&```D?_,Z8$X`20$``4?__[*ZX0(`"`HB``(D__^.@$P`!``%YSD!``
M%*Z2(``B3__SZ`3``!!O_R8!````?__\'P$```!``%YJD!``%A!O_]ZP$``(
MD!``%:X5XTRN!X`7K@7@!'__^94!````@*(@`")```C0!<``0`!>70$```"L
MDB``,D?^Y>H-@`#0!<``PDH``("@8``23__SK@7@!"T``%80;_[QK!6AT!4_
M__\O/__?E!*C[I80(`*N%>-8DA)C_T``79:@!X`7D!``%I00(`9``%VJDA``
M$,(/@!>`H&``$D``!Y`0`!;"#"`!@*!@0R)``.G"#"`"D!``%I(0(`"4$"``
M0`!=A980(`#`)[]L`QG12#4__]_`)[]P@A!C`<(GOUBT%J-8`SOS:J`'OUC`
M)[^T@A!CB<(GOURT!X`:`R8NM[8'OW2"$&#^PB>_8`,$#)6"$&!VPB>_9`,P
M]+B"$&'PPB>_:)`0`!:2$``:0`!=@A4``""ZDB``!$``/L('OVR%+V`#A`"`
M`8"@0`(82``WQ@>_<(DW8!W"![^TN!``&H8`P`3$)[]L@*!@``)(`!/&)[]P
MN!`@0)`&P`&X)P`!DA``&H"G0!RY9(`=0`!=FI00`!S"![^T@@<``8"@8$`2
M3__APB>_M)`0`!"Z)T`<?__T&+@&@!R`IV`_!$``%I(0`!RN$"``D@<`%Y00
M($"0$``;0`!=B*X%X$!___0-D!``$((G0!>`H&`_%$__^)('`!>Z!W_`@S=@
M!H4H8`:"`&`!@RA@!KHG0`*X!P`!DA``')`0`!M``%UWE!``'1!O_\'Z)[^T
M$&__RX8`X`%``%V,D!``%OH'OVSX![]PAA`_@(,W8`.""&`_A`>``8(`8`&`
MH&`X%$``6\8HOW24$"`XD`;``90B@`%``%TFDA`@`(,W(!C"+[^LD!``$(,W
M(!#"+[^MH`>_N(,W(`C"+[^NKA``$(,W8!C"+[^PK!`@`(,W8!#X+[^ON`>_
MZ/HOO[.[-V`(PB^_L?HOO[)___/4.P``5MH'OUBZ%V&@R`>_7,8'OV"9,V`8
MQ`>_9),S8!"4$``,P@>_:)<S8`B1,2`8V"^_Z-(OO^F9,.`8DS$@$-8OO^K:
M+[_KES$@")LPX!#0+[_LTB^_[9$PX`C6+[_NDS"@&,@OO^^7,*`0V"^_\(DP
M8!"9,*`(VB^_\<8OO_.;,&`8AS!@"-`OO_+2+[_TUB^_]=@OO_;$+[_WVB^_
M^,@OO_G&+[_Z$&@``\(OO_O4#P`6D!``%Y0*H/^2$``=0`!=CJP%H`&`I:`4
M$D__^:X%X`(3``!6EA``%<`OO^"2$F&0F!``$)H48T"0$``30`!=@I00`!00
M;_[/`0```)00($"2$"``E"*``4``7,V0!L`!?__SCI`0`!#`)N`TP">_=,`F
MX`3`)N`(P";@#,`FX!#`)N`4P";@&,`FX!S`)N`@P";@),`FX"C`)N`L$&__
MF,`FX#!``%R!`0````,``+'8`@``$P``5M0&``"2$F$@EA``%-``83A``%T1
ML!`@`!!O_LT!````@*!@01)/_QF0$``6P@P@`X"@8$,23_\6DA`@`,(,(`2`
MH&!($D__$Y00(`#"#"`%@*!@11)/_P^6$"`"$S___Q4___^0$``6E!*CQD``
M7(Z2$F/_DA``$)`0`!9``%RBE!`@*1,``%:0$``3DA)AD)80`!68$``0FA1C
M0$``73R4$``4$&_^B0$```!``%SS`0````$````!`````0```)WCOZ!``%T@
MD!`@`$``7(O0`@``0`!<H0$```""$"`!PBH``!$``%5___A6D!(C:("B(``"
M0``&`0```,)*``"`H&`Q(D``I<)*(`%___L=`0```$``70R0$"``0`!<=]`"
M```3``!6E!`@`9(28=A``%QFEA`@"X"B(``"0``]+0``M<0"(`RB$"`$P@6A
M>*`0(`"`H&`!!$``,N8`H!@I``"UJA6A>!!H``ZH%2%\T@!@#$``7/J0$``2
M@*(@`!)``"C"!:%XH`0@`<(%0`"$!"`!@*!``@1``"*B!&`$0`!<Z9`0(`!`
M`%Q4T`(``)(0`!.4$``00`!<F)80(`"NDB```D``%\(%H7C"!<``Q@4``,0`
M8`B`B*0`$D__Y>0`P!%``%S8D!`@`$``7$/0`@``T@7``)00(`!``%SMEA`@
M`I(0``A``%S5D!``$H"B(``B3__>H`0@`<(%H7B$`'__@*"`$`)``&&`H&`!
M0`!<Q9`0(`!``%PPT`(``!,``%:4$"`!DA)AX$``7!^6$"`%H)(@``)``!(!
M````0`!<N9`0(`!``%PDT`(``,($(`P5``!6E!*AZ$``7!G2`$``P@0@#,(`
M0`#$`&`(`P`0`("(@`$20`!6`0```$``7*F0$"``0`!<%-`"```3``!6E!`@
M`9(28?!``%P#EA`@!:"2(``B0``1D!`@`!$``%5___?;D!(CN**2(``"0`!-
M`0```$``7)>0$"``0`!<`M`"``#"!"`,E!``$4``6_C2`$``D!`@`$``7(XE
M``"U0`!;^=`"``!``%P/`0```,`J``!``%R'D!`@`$``6_+0`@``0`!<C`$`
M``#`(@``$0``57__][Z0$B.(@*(@``)``#S0)*%T0`!;KI(0(>V"&B`1@*``
M`81`(`"`H``(@D`@`("(@`$"0``%EA``"("B/_\20`!*`P``M8'/X`@!````
M@*!@``)/_UX!````$&__6@$````$1_^AH!`@`2,``+6B%&%XD!`@`$``7&&@
M!"`!0`!;S-`"``!``%N[DA``$\($0`"`H$`0-$__^)`0(``0;_^2`0```$``
M7%60$"``0`!;P-`"``#"!"`,0`!<&M(`0``0;_^E`0```$``7$P!````0`!;
MM]`"```#``"UQ`0@#,(`87S2`(``?__WN]0`0``0;_^TD!`@`",``+5___R6
MT`1A?-`DH73"!"`,P@!``,0`8`B`B*0``D``)`$```#0`&`,0`!;V-($87S"
M!"`,Q`1A?,(`0`#B`(``Q`!@"("(I``"0``.I!``"-0`8`P1``!6DA``$9`2
M(?A``%P)EA``$A$``%;4!*%TP@!A?)`2(BA``%P#T@!``$``7!^0$"``0`!;
MBM`"``#"!"`,E!`@`)80(`)``%PST@!``!!O_^R4$``(0`!<%)`0(`!``%M_
MT`(``,($(`R4$"``EA`@`D``7"C2`$``$&__U@$```"=X[^@D!`@`$``7`<S
M``!6T`(``#4``+`W``!6LA9B>$``6VZT%J+HL!``"!"`6_B7[N*8`0````$`
M```!````G>._H)`0(`!``%OW-P``5=`"``"V%N-`,P``5C4``%1``%M>NA`@
M`'___^:R%F*H0`!;[9`0(`#0`@``M!:@($``6U:X$``;$(!;?I'H``@!````
M,&@``P$````!````@</@"*X#P!<P:``&`0````$````!`````0````$```"=
MX[^@`P```"\``%I____UK@7CP((08`C"!<`!@*!@``)```.V$"``]@!``!"`
M6R.!Z````0````$````!````@</@"`$```"!P^`(K@/`%S!H``0!`````0``
M``$```"=X[^@+P``6G____BN!>-D0`!;T@$````%`````P```((08!"$$*`,
MX@7``>0%P`*D)(`1@SR@'X&`8`"D_*`$`D``"Z`0(`#"!$``D!``&)(0`!F4
M$``:G\!``*`$(`&`I``2"D__^:($8`2!S^`(`0```#!H``,!`````0```)WC
MOZ`A``"PH!0@!,($/_R`H'__`D``"*`$/_R?P$``H`0__,($``"`H'__$D__
M_`$```"!S^`(`0````$```"=X[^@@<_@"`$````P:``%`0````$````!````
M`0```)WCOZ!___%7`0```(''X`B!Z``````````"``$`````4$%27T-,14%.
M`````````"]P<F]C+W-E;&8O97AE```N`````````"XN````````)7,O)7,`
M```O<')O8R\E:2\E<P``````97AE``````!,1%],24)205)97U!!5$@`3$E"
M4$%42`!,24)205)97U!!5$@`````1%E,1%],24)205)97U!!5$@`````````
M)7,E<R5S``!015),-4Q)0@``````````4$523$Q)0@!015),-4]05```````
M````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140``````%!!
M4E]414U0``````````!005)?1$5"54<`````````4$%27T-!0TA%````````
M`%!!4E]04D]'3D%-10````!005)?05)'0P``````````4$%27T%21U9?,```
M`````%!!4E]'3$]"04Q?1$5"54<``````````%!!4E]'3$]"04Q?5$U01$E2
M`````````%!!4E]435!$25(```````!005)?1TQ/0D%,7U1%35``4$%27T=,
M3T)!3%]#3$5!3@``````````4$%27T-,14%./0```````#$`````````<&%R
M+0`````E<P```````"UE````````+2T```````!#.EQ414U0`"]T;7``````
M5$U01$E2``!414U01$E2`%1%35``````5$U0``````!54T52`````%5315).
M04U%```````````E<R5S)7,E<P``````````)7,Z(&-R96%T:6]N(&]F('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````
M`"5S.B!S=&%T(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N
M<V%F90H``'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)3`R>```
M```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``````````4UE3
M5$5-``!!4D=6`````!@`````````<&5R;``````P`````````"5S.B!E>&5C
M=71I;VX@;V8@)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*`"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E('1E;7!O<F%R>2!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*````1'EN84QO861E<CHZ8F]O
M=%]$>6YA3&]A9&5R``````!P97)L>'-I+F,`````````26YT97)N86QS.CI0
M05(Z.D)/3U0`````+P`````````Z`````````%]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@```````!6L```5K(````````````````0<____^`
M``!P87(N<&P``",A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI
M;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM
M(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP
M:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P
M87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6
M>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E
M<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,[
M"B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?
M=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD
M("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@
M)'!A<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@
M=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T
M(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N
M="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4
M:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@
M=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R
M87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL:6YK
M('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O
M('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E
M<W,N"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E
M8V%U<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@
M8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@
M/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M
M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC;60G
M+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@
M("!P<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@
M,3`@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@
M)R1P87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE
M97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF
M:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^
M9FEL96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@
M)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@
M("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A
M8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@
M("`@("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*
M("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV*"D[
M"@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%2
M1U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]
M+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!
M4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@
M("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]
M"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N
M86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P
M871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*
M("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG
M=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/
M(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G
M;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C
M:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D
M<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%2
M3E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T
M87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P
M<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B
M=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@
M.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@
M('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@
M('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E
M860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@
M+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN
M=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE
M("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T
M.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q
M*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@
M)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@
M)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D
M8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@
M7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD("1E
M>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY
M("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@
M("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D
M92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@
M("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C:&UO
M9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U
M;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E
M;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%2
M7U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)
M0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G
M/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H
M)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@
M("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@
M("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@
M("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@
M("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C<F,@
M/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@
M("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U
M9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@
M>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@
M<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M
M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\
M?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A
M8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X
M="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y
M(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L971E
M("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@
M("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A
M9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%2
M7T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@
M("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D
M(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN
M="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L
M(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T
M96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@
M(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@
M("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@
M("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@
M("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F
M:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@
M("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN
M:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E
M(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER
M92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@
M("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W
M(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN
M"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H
M92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG
M0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@
M("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O
M0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@
M;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N
M86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I<F4@
M)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O
M;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N
M;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL
M97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@
M>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"@HD
M<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N)W0@<W=A
M;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO
M=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=
M(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T
M7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@
M("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@
M("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D[
M"@H@("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA;64@+2UP
M87(M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L"B`@("`C
M('5S92!T:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E
M860@;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L9B`H8G5T
M('-T:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@
M0$E.0RD*("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["B`@("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM005)?05!0
M7U)%55-%?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS92![(",@;F]R
M;6%L('!A<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?:6YC.PH@
M("`@("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D05)'5ELP72`]
M?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@
M("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@<'5S:"!`
M861D7W1O7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A;"`B=7-E("0R
M(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T$G
M*2!["B`@("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@
M("`@("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@("`@("1B
M=6YD;&4@/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M:68@*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=A
M;&PG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M<2<I('L*("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@
M("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN
M;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C:&5?;F%M
M92`]("0R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S:&EF="A`05)'
M5BD["@H@("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI
M('L*("`@("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@
M("`@("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@("`@(')E
M<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@("`F>R)0
M05(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@("`@
M("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=6YS
M:&EF="!`24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@+2T@861D
M("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H
M+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L
M;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7
M:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U
M:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H
M0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@
M>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN
M;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@
M("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M("D*("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B
M.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B`@("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@
M("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@
M/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@
M("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A
M;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O
M<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@
M(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2
M(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@
M("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&
M:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I
M;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<
M)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY
M("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@
M("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P
M*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@
M>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@
M("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@
M("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B
M.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A
M;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@
M("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N
M9W1H*"1S970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT
M*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7
M<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@
M("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@
M("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S
M;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@
M("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@
M('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP
M?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV
M;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C($9I;&4@97AI
M<W1S('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@("`C($9U
M;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S
M<R]287<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@
M8F%N9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H92!I<W-U
M92X*("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H('1H92!P
M86EN(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@("`@
M("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I;&5S.PH@
M("`@("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@
M9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S
M("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG
M>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E
M86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M
M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC
M*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@
M)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#
M8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E
M<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I9B`H+68@
M(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@
M)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@
M9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@
M("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@
M("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE
M+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@
M("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@
M("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE
M(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@
M("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@
M/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@
M("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"@H@("`@("`@("`@("`@("`@(R!$;R!N;W0@;&5T(%A33&]A9&5R('!I8VL@
M=7`@875T;R\J(&9R;VT@96YV:7)O;FUE;G0*("`@("`@("`@("`@("`@("1C
M;VYT96YT(#U^(',O9V]T;R`K<F5T<GD@*W5N;&5S<R`K+BHO9V]T;R!R971R
M>3LO"B`@("`@("`@("`@("`@("`@("`@:68@;&,H)&YA;64I(&5Q(&QC*")8
M4TQO861E<BYP;2(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!O=71S
M*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R
M:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H
M<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ
M6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@
M("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H
M*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT
M*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E
M(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^
M=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N
M86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A
M8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@
M("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@
M("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T
M.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I
M;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V
M97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`[
M"B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V
M97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE
M*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O
M=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@
M8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@
M("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A
M8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F
M:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C
M:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]
M"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM[
M"GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?
M9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@
M86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E
M(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@
M("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?
M(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&
M:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@
M;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I
M(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R
M(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP
M.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[
M4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@(&EF("AD969I
M;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES
M('!O:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE
M;6)E<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E
M8W1O<GD["B`@("`@("`@("`@(&UY("1M96UB97)?;F%M92`]("1M96UB97(M
M/F9I;&5.86UE.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA
M;64@/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@("`@("`@("`@("`@("\_
M<VAL:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R
M<VEO;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;F%M97TO*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*("`@("`@("`@
M("`@("`@("0*("`@("`@("`@("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R
M86-T7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PH@("`@("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]
M("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@
M("`@;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A
M;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B
M)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@
M("`@("1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*
M("`@("`@("`@("`@("`@(&-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>
M3R!E<2`B:'!U>"(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@
M("`C('U]?0I]"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R
M=6XL('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;
M+4]O=71F:6QE72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@
M0W)E871E4&%T:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E
M<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T
M:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H
M)UPN+BHG*2D["B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@
M("`@1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I
M.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D
M=6QE<R!["B`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I
M9B`D7D\@;F4@)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q
M=6ER92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q
M=6ER92!S=')I8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER
M92!V87)S.PH@("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(
M96%V>3L*("`@(')E<75I<F4@17)R;F\["B`@("!R97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C
M;G1L.PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE
M.CI3<&5C.PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@0V]N
M9FEG.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ
M1FEL93L*("`@(')E<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E
M($%R8VAI=F4Z.EII<#L*("`@(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!0
M05(Z.DAE879Y.PH@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@(')E<75I<F4@871T<FEB=71E
M<SL*("`@(&5V86P@>R!R97%U:7)E($-W9"!].PH@("`@979A;"![(')E<75I
M<F4@5VEN,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!]
M.PH@("`@979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T[
M"B`@("!E=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!]
M.PH@("`@979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ
M<V-A;&%R('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P
M96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV
M97,@:6X@4$%2.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B
M(%]S971?<&%R7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P
M87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E
M86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q
M=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL
M97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*
M("`@("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@
M("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@
M>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@
M("`@("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@
M("`@("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@
M("`@?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@
M("`@("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\
M?"`D14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*("`@("`@("`D
M=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@
M(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@("`@("`@
M;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#
M3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2![
M"B`@("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@
M("`@("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R
M96%D("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@97$@
M(EPP0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R
M.PH@("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@
M("`@("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@
M("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E
M<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@
M5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N
M,SD*("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D
M1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H
M)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@
M("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH
M97AD:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!C;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@
M("`@("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@("1P
M87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E
M>'0L("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@
M("1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF
M("UE("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA
M;64["B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D
M9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@
M)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F
M:"D["B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC('-A;64@8V]D
M92!L:79E<R!I;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS
M=6(@7W-E=%]P<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]0
M4D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*
M("`@("`@("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@
M?'P]("0P.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G
M;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM
M?2D@/CT@,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@
M("!]"B`@("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@
M>PH@("`@("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F;W)E86-H
M(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-
M4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]
M?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA
M;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G
M;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I
M"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(CL*("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D
M<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@
M)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@
M?0H*("`@(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D
M<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*
M("`@("`@("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_
M(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@
M("`@)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I
M9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@
M<F5T=7)N.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#
M3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@
M("`@("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@
M*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.
M5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES
M=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R
M7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*
M"B`@("!I9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.
M5GM005)?0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM0
M05)?1TQ/0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T
M<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@
M)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%.
M/2A<4RLI+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q
M=6EE=#L*("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@
M(D!?7&XB.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB
M.PH@("`@?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<[
M"B`@("!P=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S
M:71E87)C:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(PHC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*
M"G!A8VMA9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF
M4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q
M<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z
M($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D
M<')O9VYA;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D
M0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT[
M"@HD.CI?7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#$R"@I?7T5.
M1%]?"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````_____P````#_____```````````````!`````0````$`
M``*R`````0```KT````!```"QP````$```,6`````0``!%H````,``$;4```
M``T``5:`````!``!`6QO__[U``$$R`````4``0_@````!@`!"*`````*```%
M\0````L````0````%0`````````#``+!(`````(```/,````%`````<````7
M``$7?`````<``1=,````"````_P````)````#&____X``1:\;____P````)O
M___P``$5T@``````````````````````````````````````````````````
M```````````````"P!0```````+%)``"P````L``````````````````````
M`````````````````````````````````````````````P``,#"___,!````
M`P``/#"___`!`````P``2#"__^T!`````P``5#"__^H!`````P``8#"__^<!
M`````P``;#"__^0!`````P``>#"__^$!`````P``A#"__]X!`````P``D#"_
M_]L!`````P``G#"__]@!`````P``J#"__]4!`````P``M#"__](!`````P``
MP#"__\\!`````P``S#"__\P!`````P``V#"__\D!`````P``Y#"__\8!````
M`P``\#"__\,!`````P``_#"__\`!`````P`!"#"__[T!`````P`!%#"__[H!
M`````P`!(#"__[<!`````P`!+#"__[0!`````P`!.#"__[$!`````P`!1#"_
M_ZX!`````P`!4#"__ZL!`````P`!7#"__Z@!`````P`!:#"__Z4!`````P`!
M=#"__Z(!`````P`!@#"__Y\!`````P`!C#"__YP!`````P`!F#"__YD!````
M`P`!I#"__Y8!`````P`!L#"__Y,!`````P`!O#"__Y`!`````P`!R#"__XT!
M`````P`!U#"__XH!`````P`!X#"__X<!`````P`![#"__X0!`````P`!^#"_
M_X$!`````P`"!#"__WX!`````P`"$#"__WL!`````P`"'#"__W@!`````P`"
M*#"__W4!`````P`"-#"__W(!`````P`"0#"__V\!`````P`"3#"__VP!````
M`P`"6#"__VD!`````P`"9#"__V8!`````P`"<#"__V,!`````P`"?#"__V`!
M`````P`"B#"__UT!`````P`"E#"__UH!`````P`"H#"__U<!`````P`"K#"_
M_U0!`````P`"N#"__U$!`````P`"Q#"__TX!`````P`"T#"__TL!`````P`"
MW#"__T@!`````P`"Z#"__T4!`````P`"]#"__T(!`````P`#`#"__S\!````
M`P`###"__SP!`````P`#&#"__SD!`````P`#)#"__S8!`````P`#,#"__S,!
M`````P`#/#"__S`!`````P`#2#"__RT!`````P`#5#"__RH!`````P`#8#"_
M_R<!`````P`#;#"__R0!`````P`#>#"__R$!`````P`#A#"__QX!`````P`#
MD#"__QL!`````P`#G#"__Q@!`````P`#J#"__Q4!`````P`#M#"__Q(!````
M`P`#P#"__P\!`````P`#S#"__PP!`````P`#V#"__PD!`````P`#Y#"__P8!
M`````P`#\#"__P,!`````0``````````````_____P`!6Q```%OI1T-#.B`H
M1&5B:6%N(#0N-"XU+3@I(#0N-"XU`$=#0SH@*$1E8FEA;B`T+C0N-2TQ,"D@
M-"XT+C4``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N
M9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV
M97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN
M:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+F-T;W)S`"YD=&]R
M<P`N:F-R`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```````
M````````````````````````````````````````````````````"P````$`
M```"``$!%````10````3```````````````!`````````!,````'`````@`!
M`2@```$H````(```````````````!``````````A````!P````(``0%(```!
M2````"0```````````````0`````````.`````4````"``$!;````6P```-<
M````!@`````````$````!````#1O___V`````@`!!,@```3(```#V`````8`
M````````!`````0````^````"P````(``0B@```(H```!T`````'`````0``
M``0````0````1@````,````"``$/X```#^````7Q```````````````!````
M`````$YO____`````@`!%=(``!72````Z`````8``````````@````(```!;
M;____@````(``1:\```6O````)`````'`````@````0`````````:@````0`
M```"``$73```%TP````P````!@`````````$````#````'0````$`````@`!
M%WP``!=\```#S`````8````6````!`````P```!^`````0````8``1M(```;
M2````%````````````````0`````````A`````$````&``$;H```&Z```#K@
M```````````````@`````````(H````!````!@`!5H```%:`````%```````
M````````!`````````"0`````0````(``5:8``!6F```8'``````````````
M``@`````````F`````$````"``&W"```MP@````$```````````````$````
M`````*(````!`````P`"P````,``````"```````````````!`````````"I
M`````0````,``L`(``#`"`````@```````````````0`````````L`````$`
M```#``+`$```P!`````$```````````````$`````````+4````&`````P`"
MP!0``,`4````^`````<`````````!`````@```"^`````0````,``L$,``#!
M#````!0```````````````0````$````>0````$````'``+!(```P2````0`
M```````````````$`````````,,````!`````P`"Q2```,4@````%```````
M````````!`````````#)````"`````,``L4X``#%-```$$@`````````````
M``@`````````S@````$````P````````Q30````Y```````````````!````
I`0````$````#`````````````,5M````UP```````````````0``````
